##  Update the Agent Version
We periodically release new versions of the [SAP LeanIX GitHub agent![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2Fleanix%2Fleanix-github-agent "https://github.com/leanix/leanix-github-agent") to ensure optimal performance. The currently deployed version is displayed at the top of the GitHub integration page. If a new version becomes available, you'll see a notification.
For more information, see [Updating the Agent Version](https://help.sap.com/docs/leanix/ea/github-enterprise-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a5a6b7a441014ac0c9174af342681__updating_the_agent_version).
YesNo
Send
